==> mpl_plotter-3.8.1.tar.gz: mpl_plotter-3.8.1/tests/presets/MYPRESET3D.py <==
preset = {
    ## Backend
    # "backend": "Qt5Agg",
    ## Fonts
    # "font": "serif",
    # "math_font": "dejavuserif",
    # "font_color": "black",
    ## Figure
    ## axis
    # "fig": None,
    # "ax": None,
    # "figsize": None,
    # "shape_and_position": 111,
    # "azim": 54,
    # "elev": 25,
    ## Setup
    # "prune": None,
    # "resize_axes": True,
    # "aspect": 1,
    # "box_to_plot_pad": 10,
    ## Spines
    # "spines_juggled": (1, 0, 2),
    # "spine_color": None,
    # "workspace_color": None,
    # "workspace_color2": None,
    # "background_color_figure": "white",
    # "background_color_plot": "white",
    # "background_alpha": 1,
    # "style": None,
    # "light": None,
    # "dark": None,
    # "pane_fill": None,
    ## Bounds
    # "x_upper_bound": None,
    # "x_lower_bound": None,
    # "y_upper_bound": None,
    # "y_lower_bound": None,
    # "z_upper_bound": None,
    # "z_lower_bound": None,
    # "x_bounds": None,
    # "y_bounds": None,
    # "z_bounds": None,
    ## Pads
    # "demo_pad_plot": False,
    # "x_upper_resize_pad": 0,
    # "x_lower_resize_pad": 0,
    # "y_upper_resize_pad": 0,
    # "y_lower_resize_pad": 0,
    # "z_upper_resize_pad": 0,
    # "z_lower_resize_pad": 0,
    ## Grid
    # "grid": True,
    # "grid_color": "lightgrey",
    # "grid_lines": "-.",
    ## Color
    # "color": "darkred",
    # "cmap": "RdBu_r",
    # "alpha": 1,
    ## Title
    # "title": None,
    # "title_weight": None,
    # "title_size": 12,
    # "title_y": 1.025,
    "title_color": "pink",
    "title_font": "Pump Triline",
    ## Labels
    # "x_label": "x",
    # "x_label_bold": False,
    # "x_label_size": 12,
    # "x_label_pad": 7,
    # "x_label_rotation": None,
    # "y_label": "y",
    # "y_label_bold": False,
    # "y_label_size": 12,
    # "y_label_pad": 7,
    # "y_label_rotation": None,
    # "z_label": "z",
    # "z_label_bold": False,
    # "z_label_size": 12,
    # "z_label_pad": 7,
    # "z_label_rotation": None,
    ## Ticks
    # "x_tick_number": 5,
    # "x_tick_labels": None,
    # "y_tick_number": 5,
    # "y_tick_labels": None,
    # "z_tick_number": 5,
    # "z_tick_labels": None,
    # "x_tick_rotation": None,
    # "y_tick_rotation": None,
    # "z_tick_rotation": None,
    # "tick_color": None,
    # "tick_label_pad": 4,
    # "tick_ndecimals": 1,
    ## Tick labels
    # "tick_label_size": 8.5,
    # "tick_label_size_x": None,
    # "tick_label_size_y": None,
    # "tick_label_size_z": None,
    ## Color bar
    # "color_bar": False,
    # "cb_pad": 0.1,
    # "extend": "neither",
    # "cb_title": None,
    # "cb_orientation": "vertical",
    # "cb_axis_labelpad": 10,
    # "cb_tick_number": 5,
    # "shrink": 0.75,
    # "cb_outline_width": None,
    # "cb_title_rotation": None,
    # "cb_title_style": "normal",
    # "cb_title_size": 10,
    # "cb_top_title_y": 1,
    # "cb_ytitle_labelpad": 10,
    # "cb_title_weight": "normal",
    # "cb_top_title": False,
    # "cb_y_title": False,
    # "cb_top_title_pad": None,
    # "cb_top_title_x": 0,
    # "cb_vmin": None,
    # "cb_vmax": None,
    # "cb_ticklabelsize": 10,
    # "cb_hard_bounds": False,
    ## Legend
    # "plot_label": None,
    # "legend": False,
    # "legend_loc": "upper right",
    # "legend_size": 13,
    # "legend_weight": "normal",
    # "legend_style": "normal",
    # "legend_handleheight": None,
    # "legend_ncol": 1,
    ## Subplots
    # "show": False,
    # "newplot": False,
    ## Save
    # "filename": None,
    # "dpi": None,
    ## Suppress output
    # "suppress": True,
}

==> mpl_plotter-3.8.5.tar.gz: mpl_plotter-3.8.5/tests/presets/MYPRESET3D.py <==
preset = { 
    ## Scale 
    # "x_scale": 1, 
    # "y_scale": 1, 
    # "z_scale": 1, 
    ## Backend 
    # "backend": "Qt5Agg", 
    ## Fonts 
    # "font": "serif", 
    # "math_font": "dejavuserif", 
    # "font_color": "black", 
    ## Figure, axis 
    # "fig": None, 
    # "ax": None, 
    # "figsize": None, 
    # "shape_and_position": 111, 
    # "azim": -137, 
    # "elev": 26, 
    ## Setup 
    # "prune": None, 
    # "resize_axes": True, 
    # "aspect": 1, 
    # "box_to_plot_pad": 10, 
    ## Spines 
    # "spines_juggled": (1,0,2), 
    # "spine_color": None, 
    # "workspace_color": None, 
    # "workspace_color2": None, 
    # "background_color_figure": "white", 
    # "background_color_plot": "white", 
    # "background_alpha": 1, 
    # "style": None, 
    # "light": None, 
    # "dark": None, 
    # "pane_fill": None, 
    ## Bounds 
    # "x_upper_bound": None, 
    # "x_lower_bound": None, 
    # "y_upper_bound": None, 
    # "y_lower_bound": None, 
    # "z_upper_bound": None, 
    # "z_lower_bound": None, 
    # "x_bounds": None, 
    # "y_bounds": None, 
    # "z_bounds": None, 
    ## Pads 
    # "demo_pad_plot": False, 
    # "x_upper_resize_pad": 0, 
    # "x_lower_resize_pad": 0, 
    # "y_upper_resize_pad": 0, 
    # "y_lower_resize_pad": 0, 
    # "z_upper_resize_pad": 0, 
    # "z_lower_resize_pad": 0, 
    ## Axes 
    # "show_axes": True, 
    ## Grid 
    # "grid": True, 
    # "grid_color": "lightgrey", 
    # "grid_lines": "-.", 
    ## Color 
    # "color": "darkred", 
    # "cmap": "RdBu_r", 
    # "alpha": 1, 
    ## Title 
    # "title": None, 
    # "title_weight": "normal", 
    "title_size": 100,
    # "title_y": 1.025, 
    "title_font": "Pump Triline",
    "title_color": "pink",
    ## Labels 
    # "x_label": "x", 
    # "x_label_weight": "normal", 
    # "x_label_size": 12, 
    # "x_label_pad": 7, 
    # "x_label_rotation": None, 
    # "y_label": "y", 
    # "y_label_weight": "normal", 
    # "y_label_size": 12, 
    # "y_label_pad": 7, 
    # "y_label_rotation": None, 
    # "z_label": "z", 
    # "z_label_weight": "normal", 
    # "z_label_size": 12, 
    # "z_label_pad": 7, 
    # "z_label_rotation": None, 
    ## Ticks 
    # "x_tick_number": 5, 
    # "x_tick_labels": None, 
    # "x_custom_tick_labels": None, 
    # "x_custom_tick_locations": None, 
    # "y_tick_number": 5, 
    # "y_tick_labels": None, 
    # "y_custom_tick_labels": None, 
    # "y_custom_tick_locations": None, 
    # "z_tick_number": 5, 
    # "z_tick_labels": None, 
    # "z_custom_tick_labels": None, 
    # "z_custom_tick_locations": None, 
    # "x_tick_rotation": None, 
    # "y_tick_rotation": None, 
    # "z_tick_rotation": None, 
    # "tick_color": None, 
    # "tick_label_pad": 4, 
    # "tick_ndecimals": 1, 
    ## Tick labels 
    # "tick_label_size": 8.5, 
    # "x_tick_label_size": None, 
    # "y_tick_label_size": None, 
    # "z_tick_label_size": None, 
    ## Color bar 
    # "color_bar": False, 
    # "extend": "neither", 
    # "shrink": 0.75, 
    # "cb_title": None, 
    # "cb_axis_labelpad": 10, 
    # "cb_tick_number": 5, 
    # "cb_outline_width": None, 
    # "cb_title_rotation": None, 
    # "cb_title_style": "normal", 
    # "cb_title_size": 10, 
    # "cb_top_title_y": 1, 
    # "cb_ytitle_labelpad": 10, 
    # "cb_title_weight": "normal", 
    # "cb_top_title": False, 
    # "cb_y_title": False, 
    # "cb_top_title_pad": None, 
    # "x_cb_top_title": 0, 
    # "cb_vmin": None, 
    # "cb_vmax": None, 
    # "cb_ticklabelsize": 10, 
    ## Legend 
    # "plot_label": None, 
    # "legend": False, 
    # "legend_loc": "upper right", 
    # "legend_size": 13, 
    # "legend_weight": "normal", 
    # "legend_style": "normal", 
    # "legend_handleheight": None, 
    # "legend_ncol": 1, 
    ## Subplots 
    # "show": False, 
    # "newplot": False, 
    ## Save 
    # "filename": None, 
    # "dpi": None, 
    ## Suppress output 
    # "suppress": True, 
}
